@@ -172,6 +172,12 @@ void acs_airdk_load_from_main_thread(struct acs* acs, const char* data) {
             }
 
             ac_fill_wingspan(acs, ac);
+            int wsmeters = (int)round(ac->wingspan * 0.3048);
+            if (wsmeters > 0 && wsmeters < cfg->ac_minwingspan) {
+                g_free(ac);
+                zjson_free(one);
+                continue;
+            }
 
             g_ptr_array_add(acs->th.acs, ac);
             added++;
