@@ -213,8 +213,7 @@ int sw_map_mouse_func(struct subwin *sw, struct event *ev, int fw){
 		}
     }
 	if (ev->b & B_MOVE){
-        /*if (!gacs || !gacs->undercursor)*/ plot_nearest_qso_beacon_ac(sw, aband);
-        //plot_nearest_qrv(sw, aband);
+        plot_nearest_qso_beacon_ac(sw, aband);
         plot_qrb_qth(sw, sw->screen, sdl->mouse_x, sdl->mouse_y);
         return 1;
     }
