@@ -810,7 +810,7 @@ void add_error(struct band *b, gchar *remark){
 void qso_mark_as_error(struct band *b, gint i){
     struct qso *qso;
     
-    qso = g_ptr_array_index(b->qsos, i);
+    qso = (struct qso*)g_ptr_array_index(b->qsos, i);
     qso->error = 1;
     qso->qsop = 0;
     dirty_band(b);
@@ -1132,7 +1132,7 @@ GPtrArray *get_band_qs(struct band *band, gchar *str){
         if (qs->result1->len == term->y - QSONR_HEIGHT - 4 - cfg->loglines - ctest->spypeers->len - 1) break;
         
         if (qso->callsign && z_strstr(qso->callsign, qs->str)){
-			stats_valid_key_display(valid, qso->callsign, qso->locator, qso->phase, qso->mode);
+			stats_valid_key_display(valid, qso->callsign, qso->locator, qso->phase, (enum modes)qso->mode);
             if (qso->locator)
 				c = g_strdup_printf("%-10s %-6s%5d/%3d", valid, qso->locator, (int)qso->qrb, qso->qtf);
             else
@@ -1143,7 +1143,7 @@ GPtrArray *get_band_qs(struct band *band, gchar *str){
         }
         
         if (qso->locator && z_strstr(qso->locator, qs->str)){
-			stats_valid_key_display(valid, qso->callsign, qso->locator, qso->phase, qso->mode);
+			stats_valid_key_display(valid, qso->callsign, qso->locator, qso->phase, (enum modes)qso->mode);
 			if (qso->callsign)
 				c = g_strdup_printf("%-10s %-6s%5d/%3d", valid, qso->locator, (int)qso->qrb, qso->qtf);
             else
@@ -1199,7 +1199,7 @@ GPtrArray *get_oband_qs(struct band *oband, gchar *str){
                 for (j=0;j<qs->result1->len; j++){
                     char d[20], *pd, *line;
                     
-                    safe_strncpy(d, line=g_ptr_array_index(qs->result1,j), 10);
+                    safe_strncpy(d, line=(char *)g_ptr_array_index(qs->result1,j), 10);
                     pd = strchr(d, ' ');
                     if (pd) *pd='\0';
                     
