@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2023  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -632,7 +632,7 @@ test_queue:
     }
     if (ev->ev == EV_SDLRESIZE){
 #ifdef Z_HAVE_SDL        
-        dbg("EV_SDLRESIZE(%d,%d) (%d,%d)\n", ev->x, ev->y, sdl->resize_w, sdl->resize_h/*ev->mx, ev->my*/);
+        //dbg("EV_SDLRESIZE(%d,%d) (%d,%d)\n", ev->x, ev->y, sdl->resize_w, sdl->resize_h/*ev->mx, ev->my*/);
 		MUTEX_LOCK(sdl->eventpipestate);
 		sdl->resizeevents--;
 		MUTEX_UNLOCK(sdl->eventpipestate);
